@@ -1,21 +1,19 @@
-from typing import Any, Union
+from typing import Any, Hashable, Tuple
 
 from .base import BaseCacheBackend
 
-
-DEFAULT_TIMEOUT = 0
 CACHE_KEY = 'IN_MEMORY'
 
 
-class InMemoryCacheBackend(BaseCacheBackend):
+class InMemoryCacheBackend(BaseCacheBackend[Hashable, Any]):
     def __init__(self):
         self._cache: dict = {}
 
     async def add(
         self,
-        key: Union[str, int],
+        key: Hashable,
         value: Any,
-        timeout: int = DEFAULT_TIMEOUT
+        **kwargs,
     ) -> bool:
         if key in self._cache:
             return False
@@ -25,22 +23,28 @@ class InMemoryCacheBackend(BaseCacheBackend):
 
     async def get(
         self,
-        key: Union[str, int],
-        default: Union[str, int] = None
+        key: Hashable,
+        default: Any = None,
+        **kwargs
     ) -> Any:
         return self._cache.get(key, default)
 
     async def set(
         self,
-        key: Union[str, int],
+        key: Hashable,
         value: Any,
-        timeout: int = DEFAULT_TIMEOUT
+        **kwargs,
     ) -> bool:
         self._cache[key] = value
 
         return True
 
-    async def delete(self, key: Union[str, int]) -> bool:
+    async def exists(self, *keys: Tuple[Hashable]) -> bool:
+        return any(
+            map(lambda key: key in self._cache, keys)
+        )
+
+    async def delete(self, key: Hashable) -> bool:
         if key not in self._cache:
             return False
         del self._cache[key]
